==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/content/messages/sv/base.php <==
<?php
return array (
  '<strong>Confirm</strong> post deletion' => '<strong>Bekräfta</strong> radering av post',
  '<strong>Move</strong> content' => '<strong>Flytta</strong> Innehåll',
  '<strong>Permalink</strong> to this post' => '@@@@',
  'Add a member to notify' => 'Lägg till en medlem att meddela',
  'Archived' => 'Arkiverad',
  'Back to stream' => '',
  'Cancel' => 'Avbryt',
  'Cancel Edit' => 'Avbryt ändra',
  'Content' => 'Innehåll',
  'Content Tag with invalid contentcontainer_id assigned.' => '',
  'Content has been moved to {spacename}' => 'Innehållet har blivit flyttat till {spacename}',
  'Content visibility' => 'Synlighet',
  'Could not delete content!' => 'Kunde inte radera innehåll!',
  'Could not delete content: Access denied!' => 'Kunde radera innehåll: Åtkomst nekad!',
  'Could not find requested content!' => '',
  'Could not load requested object!' => '',
  'Created by me' => 'Skapade av mig',
  'Creation time' => 'Skapad',
  'Delete' => 'Ta bort',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Vill du verkligen radera? Alla kommentarer tas bort!',
  'Edit' => 'Ändra',
  'Filter' => 'Filtrera',
  'Include archived content' => '',
  'Invalid content id given!' => 'Felaktigt content id angivet!',
  'Invalid request method!' => '',
  'Invalid space selection.' => 'Felaktigt nätverk.',
  'Last update' => 'Senast uppdaterad',
  'Load more' => 'Ladda mer',
  'Make private' => 'Gör privat',
  'Make public' => 'Gör publik',
  'Maximum number of pinned items reached!

You can pin to top only two items at once.
To however pin this item, unpin another before!' => '',
  'Move content' => 'Flytta inehåll',
  'Move to archive' => 'Arkivera',
  'No matches with your selected filters!' => '',
  'None' => 'Inga',
  'Nothing here yet!' => '',
  'Notify members' => 'Meddela medlemmar',
  'Only private content' => '',
  'Only public content' => '',
  'Permalink' => '@@@@',
  'Pin to top' => '',
  'Pinned' => 'Fastnålad',
  'Public' => 'Publik',
  'Submit' => 'Skicka',
  'Tag' => 'Tagg',
  'Target Space' => 'Målnätverk',
  'The author of this content is not allowed to create private content within the selected space.' => '',
  'The author of this content is not allowed to create public content within the selected space.' => '',
  'The content can\'t be moved to its current space.' => '',
  'The content has been archived.' => '',
  'The content has been deleted.' => '',
  'The content has been unarchived.' => '',
  'The given name is already in use.' => 'Namnet används redan.',
  'The module {moduleName} is not enabled on the selected target space.' => '',
  'This action is disabled!' => '',
  'This content type can\'t be moved due to a missing module-id setting.' => '',
  'This content type can\'t be moved.' => '',
  'This space is archived.' => 'Nätverket är arkiverat.',
  'This space is not visible!' => '',
  'Topics' => 'Ämnen',
  'Turn off notifications' => 'Sätt på notiser',
  'Turn on notifications' => 'Stäng av notiser',
  'Unarchive' => 'Återställ',
  'Unpin' => '',
  'Updated' => 'Uppdaterad',
  'Where I\'m involved' => '',
  'With file attachments' => '',
  'You do not have the permission to move this content to the given space.' => '',
  'You do not have the permission to move this content.' => '',
  'Your last edit state has been saved!' => '',
  'in' => 'i',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/content/messages/sv/base.php <==
<?php
return array (
  '<strong>Confirm</strong> post deletion' => '<strong>Bekräfta</strong> radering av post',
  '<strong>Move</strong> content' => '<strong>Flytta</strong> Innehåll',
  '<strong>Permalink</strong> to this post' => '@@@@',
  'Add a member to notify' => 'Lägg till en medlem att meddela',
  'Archived' => 'Arkiverad',
  'Back to stream' => 'Tillbaka till flöde',
  'Cancel' => 'Avbryt',
  'Cancel Edit' => 'Avbryt ändra',
  'Content' => 'Innehåll',
  'Content Tag with invalid contentcontainer_id assigned.' => '',
  'Content has been moved to {spacename}' => 'Innehållet har blivit flyttat till {spacename}',
  'Content visibility' => 'Synlighet',
  'Could not delete content!' => 'Kunde inte radera innehåll!',
  'Could not delete content: Access denied!' => 'Kunde radera innehåll: Åtkomst nekad!',
  'Could not find requested content!' => 'Hittade inte eftersökt innehåll!',
  'Could not load requested object!' => 'Kunde inte ladda objektet!',
  'Created by me' => 'Skapade av mig',
  'Creation time' => 'Skapad',
  'Delete' => 'Ta bort',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Vill du verkligen radera? Alla kommentarer tas bort!',
  'Edit' => 'Ändra',
  'Filter' => 'Filtrera',
  'Include archived content' => 'Inkludera arkiverat innehåll',
  'Invalid content id given!' => 'Felaktigt content id angivet!',
  'Invalid request method!' => 'Felaktig anropsmetod',
  'Invalid space selection.' => 'Felaktigt nätverk.',
  'Last update' => 'Senast uppdaterad',
  'Load more' => 'Ladda mer',
  'Make private' => 'Gör privat',
  'Make public' => 'Gör publik',
  'Maximum number of pinned items reached!

You can pin to top only two items at once.
To however pin this item, unpin another before!' => '',
  'Move content' => 'Flytta inehåll',
  'Move to archive' => 'Arkivera',
  'No matches with your selected filters!' => 'Inga träffar i dina valda filter',
  'None' => 'Inga',
  'Nothing here yet!' => 'Ingenting här ännu!',
  'Notify members' => 'Meddela medlemmar',
  'Only private content' => 'Endast privat innehåll',
  'Only public content' => 'Endast publikt innehåll',
  'Permalink' => '@@@@',
  'Pin to top' => 'Fäst i toppen',
  'Pinned' => 'Fastnålad',
  'Public' => 'Publik',
  'Submit' => 'Skicka',
  'Tag' => 'Tagg',
  'Target Space' => 'Målnätverk',
  'The author of this content is not allowed to create private content within the selected space.' => '',
  'The author of this content is not allowed to create public content within the selected space.' => '',
  'The content can\'t be moved to its current space.' => '',
  'The content has been archived.' => '',
  'The content has been deleted.' => '',
  'The content has been unarchived.' => '',
  'The given name is already in use.' => 'Namnet används redan.',
  'The module {moduleName} is not enabled on the selected target space.' => '',
  'This action is disabled!' => '',
  'This content type can\'t be moved due to a missing module-id setting.' => '',
  'This content type can\'t be moved.' => '',
  'This space is archived.' => 'Nätverket är arkiverat.',
  'This space is not visible!' => '',
  'Topics' => 'Ämnen',
  'Turn off notifications' => 'Sätt på notiser',
  'Turn on notifications' => 'Stäng av notiser',
  'Unarchive' => 'Återställ',
  'Unpin' => '',
  'Updated' => 'Uppdaterad',
  'Where I\'m involved' => '',
  'With file attachments' => '',
  'You do not have the permission to move this content to the given space.' => '',
  'You do not have the permission to move this content.' => '',
  'Your last edit state has been saved!' => '',
  'in' => 'i',
);
